##  Linking Discovered Items to Fact Sheets
After you set up the integration, the discovery process identifies your deployed applications and SAP BTP services bound to them. It lists them in the SAP discovery inbox. In the inbox, you can review the discovered items and link them to existing fact sheets or create and link new ones. For more information, see [SAP Discovery Inbox](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "Discovered products, services, and extensions from your SAP landscape appear in the SAP discovery inbox. Learn how to create, link, and reject fact sheets related to discovered items.").
Multitarget applications are represented as applications, and related applications are modeled with the microservice fact sheet subtype. For more information about multitarget applications, visit [Multitarget Applications in the Cloud Foundry Environment](https://help.sap.com/docs/btp/sap-business-technology-platform/multitarget-applications-in-cloud-foundry-environment "https://help.sap.com/docs/btp/sap-business-technology-platform/multitarget-applications-in-cloud-foundry-environment").
When you link a deployed SAP BTP, Cloud Foundry application to an application fact sheet, the corresponding reference catalog items automatically link to that fact sheet. This linking ensures that catalog information is automatically synchronized and continuously updated in the linked fact sheets. It also keeps IT component and provider information current in their respective fact sheets.
The specific information updated depends on the data fields that you select for synchronization. For more details, refer to [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD").
